@@ -1,4 +1,5 @@
 from audobject import define
+from audobject import resolver
 from audobject.core.api import (
     from_dict,
     from_yaml,
@@ -20,6 +21,7 @@ from audobject.core.object import (
 )
 from audobject.core.resolver import (
     FilePathResolver,
+    FunctionResolver,
     TupleResolver,
     TypeResolver,
     ValueResolver,
